@@ -18,10 +18,10 @@ f3 = f4 0
 
 -- HsQualTy
 f4 :: Show a => a -> Int
-f4 _ = f5 0 0
+f4 n = f5 (show n) 0
 
 -- HsFunTy
-f5 :: Int -> Int -> Int
+f5 :: String -> Int -> Int
 f5 _ _ = head f6
 
 -- HsListTy
@@ -34,7 +34,13 @@ f7 = (fromJust f8, fromJust f8)
 
 -- HsAppTy
 f8 :: Maybe Int
-f8 = Just fError
+f8 = Just f9
+
+f9 :: Int
+f9 = f10
+  where
+    f10 :: Int
+    f10 = fError
 
 -- HsTyVar
 fError :: Int
